@@ -1,24 +1,30 @@
 from __future__ import annotations
 
 from typing import Union, List
-from logging import info
 
 from appium.webdriver.webdriver import WebDriver as AppiumDriver
 from selenium.common.exceptions import WebDriverException
 from selenium.webdriver.remote.webdriver import WebDriver as SeleniumWebDriver
 
+from dyatel.dyatel_sel.sel_utils import ActionChains
+from dyatel.exceptions import DriverWrapperException
+from dyatel.mixins.log_mixin import LogMixin
 
-class CoreDriver:
+
+class CoreDriver(LogMixin):
+    all_drivers: Union[List[AppiumDriver], List[SeleniumWebDriver]] = []
     driver: Union[AppiumDriver, SeleniumWebDriver] = None
-    driver_wrapper: CoreDriver = None
+    driver_wrapper = None
 
     desktop = False
+    selenium = True
+    playwright = False
 
     mobile = False
     is_ios = False
     is_android = False
-    is_safari_driver = False
     is_xcui_driver = False
+    is_safari_driver = False
 
     def __init__(self, driver: Union[AppiumDriver, SeleniumWebDriver]):
         """
@@ -30,6 +36,7 @@ class CoreDriver:
         driver.implicitly_wait(0.001)  # reduce selenium wait
         self.driver = driver
         self.driver_wrapper = self
+        self.all_drivers.append(driver)
         self.original_tab = driver.current_window_handle
 
         if not CoreDriver.driver:
@@ -43,12 +50,12 @@ class CoreDriver:
         :param url: url for navigation
         :return: self
         """
-        info(f'Navigating to url {url}')
+        self.log(f'Navigating to url {url}')
 
         try:
             self.driver.get(url)
         except WebDriverException:
-            raise Exception(f'Can\'t proceed to {url}')
+            raise DriverWrapperException(f'Can\'t proceed to {url}')
 
         return self
 
@@ -83,7 +90,7 @@ class CoreDriver:
 
         :return: self
         """
-        info('Reload current page')
+        self.log('Reload current page')
         self.driver.refresh()
         return self
 
@@ -93,7 +100,7 @@ class CoreDriver:
 
         :return: self
         """
-        info('Going forward')
+        self.log('Going forward')
         self.driver.forward()
         return self
 
@@ -103,7 +110,7 @@ class CoreDriver:
 
         :return: self
         """
-        info('Going back')
+        self.log('Going back')
         self.driver.back()
         return self
 
@@ -115,9 +122,10 @@ class CoreDriver:
         :return: self
         """
         if silent:
-            info('Quit driver instance')
+            self.log('Quit driver instance')
 
         self.driver.quit()
+        self.all_drivers.remove(self.driver)
 
         if self.driver == CoreDriver.driver:  # Clear only if original driver closed
             CoreDriver.driver = None
@@ -160,10 +168,10 @@ class CoreDriver:
 
     def execute_script(self, script: str, *args):
         """
-        Synchronously Executes JavaScript in the current window/frame.
+        Synchronously Executes JavaScript in the current window/frame
 
-        :param script: the JavaScript to execute.
-        :param args: any applicable arguments for your JavaScript.
+        :param script: the JavaScript to execute
+        :param args: any applicable arguments for your JavaScript
         :return: execution return value
         """
         return self.driver.execute_script(script, *args)
@@ -252,3 +260,18 @@ class CoreDriver:
             self.driver.close()
 
         return self.switch_to_original_tab()
+
+    def click_by_coordinates(self, x: int, y: int, silent: bool = False) -> CoreDriver:
+        """
+        Click by given coordinates
+
+        :param x: click by given x-axis
+        :param y: click by given y-axis
+        :param silent: erase log message
+        :return: self
+        """
+        if not silent:
+            self.log(f'Click by given coordinates (x: {x}, y: {y})')
+
+        ActionChains(self.driver).move_to_location(x, y).click().perform()
+        return self
