@@ -1,10 +1,11 @@
 from __future__ import annotations
 
-import time
 from typing import Union, List
 
 from appium.webdriver.applicationstate import ApplicationState
+from appium.webdriver.common.touch_action import TouchAction
 from appium.webdriver.webdriver import WebDriver as AppiumDriver
+from selenium.webdriver.common.by import By
 
 from dyatel.dyatel_sel.core.core_driver import CoreDriver
 
@@ -36,6 +37,9 @@ class MobileDriver(CoreDriver):
         self.native_context = 'NATIVE_APP'
         self.web_context = self.get_web_view_context() if self.is_xcui_driver else 'CHROMIUM'
 
+        self.top_bar_height = None
+        self.bottom_bar_height = None
+
         if self.is_app:
             if self.is_ios:
                 self.bundle_id = self.capabilities['bundleId']
@@ -146,3 +150,58 @@ class MobileDriver(CoreDriver):
         :return: list of available contexts
         """
         return self.driver.contexts
+
+    def get_top_bar_height(self) -> int:
+        """
+        iOS only: Get top bar height
+
+        :return: self
+        """
+        if not self.top_bar_height:
+            self.switch_to_native()
+            top_bar = self.driver.find_element(
+                By.XPATH,
+                '//*[contains(@name, "SafariWindow")]/XCUIElementTypeOther[1]/XCUIElementTypeOther/XCUIElementTypeOther'
+            )
+            self.top_bar_height = top_bar.size['height']
+            self.switch_to_web()
+
+        return self.top_bar_height
+
+    def get_bottom_bar_height(self, force: bool = False) -> int:
+        """
+        iOS only: Get bottom bar height
+
+        :param force: get the new value forcly
+        :return: self
+        """
+        if force or not self.top_bar_height:
+            self.switch_to_native()
+
+            bottom_bar = self.driver.find_element(
+                By.XPATH,
+                '//*[@name="CapsuleViewController"]/XCUIElementTypeOther[1]'
+            )
+            self.bottom_bar_height = bottom_bar.size['height']
+            self.switch_to_web()
+
+        return self.top_bar_height
+
+    def click_by_coordinates(self, x: int, y: int, silent: bool = False) -> MobileDriver:
+        """
+        Click by given coordinates
+
+        :param x: tap by given x-axis
+        :param y: tap by given y-axis
+        :param silent: erase log
+        :return: self
+        """
+        if not silent:
+            self.log(f'Tap by given coordinates (x: {x}, y: {y})')
+
+        if self.is_ios:
+            TouchAction(self.driver).tap(x=x, y=y).perform()
+        elif self.is_android:
+            super().click_by_coordinates(x=x, y=y, silent=True)
+
+        return self
