@@ -1,7 +1,5 @@
-from selenium.webdriver.remote.webdriver import WebDriver as SeleniumWebDriver
-
-from dyatel.dyatel_sel.core.core_driver import CoreDriver
 from dyatel.dyatel_sel.core.core_page import CorePage
+from dyatel.dyatel_sel.sel_utils import get_locator_type
 
 
 class WebPage(CorePage):
@@ -14,5 +12,5 @@ class WebPage(CorePage):
         :param locator_type: specific locator type
         :param name: name of page (will be attached to logs)
         """
-        self.driver: SeleniumWebDriver = CoreDriver.driver
-        CorePage.__init__(self, locator=locator, locator_type=locator_type, name=name)
+        self.locator_type = locator_type if locator_type else get_locator_type(locator)
+        super().__init__(locator=locator, locator_type=locator_type, name=name)
