@@ -46,7 +46,7 @@ def assert_same_images(actual_file: str, reference_file: str, filename: str, thr
         raise AssertionError(f"{base_error} Threshold is: {actual_threshold}; Possible threshold is: {threshold}")
 
 
-def get_difference(im1: Image, im2: Image) -> tuple[Image, float]:
+def get_difference(im1: Image, im2: Image):
     """
     Calculate difference between two images
 
@@ -57,7 +57,7 @@ def get_difference(im1: Image, im2: Image) -> tuple[Image, float]:
     diff = ImageChops.difference(im1, im2)
     histogram = diff.histogram()
 
-    red = reduce(
+    rms = reduce(
             operator.add,
             map(
                 lambda h, i: h * (i ** 2),
@@ -66,7 +66,7 @@ def get_difference(im1: Image, im2: Image) -> tuple[Image, float]:
             )
         )
 
-    return diff, math.sqrt(red / (float(im1.size[0]) * im1.size[1]))
+    return diff, math.sqrt(rms / (float(im1.size[0]) * im1.size[1]))
 
 
 def attach_allure_diff(actual_path: str, expected_path: str, diff_path: str) -> None:
